summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorsakimisu <[email protected]>2023-08-26 01:09:22 +0800
committersakimisu <[email protected]>2023-08-26 01:09:33 +0800
commit13877907440a80bee1e0b34f21d2f46643e67c21 (patch)
tree00b33fcb1b133804d834d0121df7e70d0b1ca39f
parentc5fc9f338e5f332f5027747f7248d508c67782fc (diff)
add config for hpmicro usb instance and irq
-rw-r--r--port/ehci/usb_glue_hpm.c25
-rw-r--r--port/hpm/usb_dc_hpm.c12
2 files changed, 19 insertions, 18 deletions
diff --git a/port/hpm/usb_dc_hpm.c b/port/hpm/usb_dc_hpm.c
index 2c4f27cd..dc1a43d1 100644
--- a/port/hpm/usb_dc_hpm.c
+++ b/port/hpm/usb_dc_hpm.c
@@ -10,6 +10,10 @@
#define USB_NUM_BIDIR_ENDPOINTS USB_SOC_DCD_MAX_ENDPOINT_COUNT
#endif
+#if !defined(CONFIG_HPM_USB_BASE) || !defined(CONFIG_HPM_USB_IRQn)
+#error "hpm dcd must config CONFIG_HPM_USB_BASE and CONFIG_HPM_USB_IRQn"
+#endif
+
/* USBSTS, USBINTR */
enum {
intr_usb = HPM_BITSMASK(1, 0),
@@ -62,7 +66,7 @@ int usb_dc_init(void)
memset(&g_hpm_udc, 0, sizeof(struct hpm_udc));
g_hpm_udc.handle = &usb_device_handle[0];
- g_hpm_udc.handle->regs = (USB_Type *)HPM_USB0_BASE;
+ g_hpm_udc.handle->regs = (USB_Type *)CONFIG_HPM_USB_BASE;
g_hpm_udc.handle->dcd_data = &_dcd_data;
uint32_t int_mask;
@@ -71,7 +75,7 @@ int usb_dc_init(void)
usb_device_init(g_hpm_udc.handle, int_mask);
- intc_m_enable_irq(IRQn_USB0);
+ intc_m_enable_irq(CONFIG_HPM_USB_IRQn);
return 0;
}
@@ -279,8 +283,8 @@ void USBD_IRQHandler(void)
}
}
-void isr_usb0(void)
+void isr_usb(void)
{
USBD_IRQHandler();
}
-SDK_DECLARE_EXT_ISR_M(IRQn_USB0, isr_usb0)
+SDK_DECLARE_EXT_ISR_M(CONFIG_HPM_USB_IRQn, isr_usb)
diff --git a/port/ehci/usb_glue_hpm.c b/port/ehci/usb_glue_hpm.c
index 5543ce2f..4425ddba 100644
--- a/port/ehci/usb_glue_hpm.c
+++ b/port/ehci/usb_glue_hpm.c
@@ -4,7 +4,11 @@
#include "hpm_usb_drv.h"
#if !defined(CONFIG_USB_EHCI_HPMICRO) || !CONFIG_USB_EHCI_HPMICRO
-#error "hpm ehci must set CONFIG_USB_EHCI_HPMICRO=1 and set CONFIG_HPM_USB_BASE=HPM_USB0_BASE"
+#error "hpm ehci must set CONFIG_USB_EHCI_HPMICRO=1"
+#endif
+
+#if !defined(CONFIG_HPM_USB_BASE) || !defined(CONFIG_HPM_USB_IRQn)
+#error "hpm ehci must config CONFIG_HPM_USB_BASE and CONFIG_HPM_USB_IRQn"
#endif
static void usb_host_mode_init(USB_Type *ptr)
@@ -28,20 +32,20 @@ static void usb_host_mode_init(USB_Type *ptr)
void usb_hc_low_level_init()
{
- usb_phy_init((USB_Type *)HPM_USB0_BASE);
- intc_m_enable_irq(IRQn_USB0);
+ usb_phy_init((USB_Type *)CONFIG_HPM_USB_BASE);
+ intc_m_enable_irq(CONFIG_HPM_USB_IRQn);
}
void usb_hc_low_level2_init()
{
- usb_host_mode_init((USB_Type *)HPM_USB0_BASE);
+ usb_host_mode_init((USB_Type *)CONFIG_HPM_USB_BASE);
}
uint8_t usbh_get_port_speed(const uint8_t port)
{
uint8_t speed;
- speed = usb_get_port_speed((USB_Type *)HPM_USB0_BASE);
+ speed = usb_get_port_speed((USB_Type *)CONFIG_HPM_USB_BASE);
if (speed == 0x00) {
return USB_SPEED_FULL;
@@ -58,15 +62,8 @@ uint8_t usbh_get_port_speed(const uint8_t port)
extern void USBH_IRQHandler(void);
-void isr_usb0(void)
+void isr_usb(void)
{
USBH_IRQHandler();
}
-SDK_DECLARE_EXT_ISR_M(IRQn_USB0, isr_usb0)
-
-#ifdef HPM_USB1_BASE
-void isr_usb1(void)
-{
-}
-SDK_DECLARE_EXT_ISR_M(IRQn_USB1, isr_usb1)
-#endif \ No newline at end of file
+SDK_DECLARE_EXT_ISR_M(CONFIG_HPM_USB_IRQn, isr_usb) \ No newline at end of file